# dis-taipan

This is basically a bunch of "application specific" common code I want to use in most of my bots, and got sick of updating multiple times when I found bugs/improvements.

Feel free to use it, or send PRs if you want to
